@@ -1,7 +1,7 @@
 import re
 
 
-def parse_bool(value, strict=True):
+def parse_bool(value):
     if type(value) == bool:
         return value
 
@@ -12,8 +12,7 @@ def parse_bool(value, strict=True):
     elif value in ['0', 'no', 'false', 'n', 'f']:
         return False
 
-    if strict:
-        raise ValueError(value)
+    return bool(value)
 
 
 def delimit(values, conjunction='and'):
